---
title: Electronic Lab Notebooks
author: Carolin Leister
tags:
  - Electronic Lab Notebooks
---

# Unit Lesson Plan

## Electronic Lab Notebooks

Aim/Goal of unit

### Location
- is it going to be online or physical
- if physical any special room type should be noted (e.g. classroom, IT lab, ...)

### Total duration
- 1.5 hours

### Number of attendees
- important to know the max group size
- can be a number range (e.g. 20-30)

### Learning objectives
- list the learning objectives that are to be achieved
- learning objectives should be devised using the verbs from the Bloom's Taxonomy
- learning objectives should be SMART

### Plan
| Duration | Topic                  | Key points/Teaching Method/Questions                                   | Activities               | Resources                  |
|----------|------------------------|------------------------------------------------------------------------|--------------------------|----------------------------|
| X mins   | Welcome / Introduction | - housekeeping  - introduce trainer and trainees - learning objectives | ice breaker              | e.g. name tags, flip chart |
| X mins   | The hook               | - focus attention - provide framework                                  | brainstorm expectations  | e.g. post-it notes         |
| X mins   | Training               | information + examples                                                 | check for understanding  | e.g. pptx + handouts       |
| X mins   | Guided practice        | trainer acts as facilitator                                            | exercise or activity     | e.g. posters and markers   |
| X mins   | Summary                | key takeaways                                                          | reinforcement assignment | e.g. cards                 |

Note: If the training is relying heavily on presentations then another option for the plan layout is to provided in a slide by slide using slide thumbnails in the topic column. In this case each row in the table should refer to a separate slide in the presentation.


### Assessment
- what, how, when
- is it going to be formative (throughout) or summative (in the end)
- results how and when

### Certificate or Badge
- micro-credentials for the unit
- if certificate or badge is issued then explain how it can be gained

### Reflection
- how did it go
- highlights: what went great
- improvement points: what went wrong

### Comments
- any additional comments from external parties acting as co-creators

# How to start

How do I start with my own material? Use the [TtT FAIR-by-Design Methodology](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/) for that.

1. **PREPARE:** Start with the **Backward instructional design process** described in [Ideating](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%201%20%E2%80%93%20Prepare/02-Preparing%20FAIR%20Learning%20Objects/02-Preparing%20FAIR%20Learning%20Objects_cont/).
	1. Purpose
	2. Target Audience
	3. Prerequisites
	4. Overall Scope of the learning materials
	5. Learning Objectives
2. **DISCOVER:** Look for already exisiting materials 
3. **DESIGN:**
	1. Concept and Structure
		1. Think about your [Content concept map](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%203%20%E2%80%93%20Design/04-Conceptualisation/04-Conceptualisation/#content-concept-map)
		2. Write your [Syllabus](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%203%20%E2%80%93%20Design/04-Conceptualisation/04-Conceptualisation/#syllabus) (higher level: course) (`syllabus.md`)
		3. Think about your [hierarchical structure](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%203%20%E2%80%93%20Design/05-Hierarchical%20Structure/05-HierarchicalStructure/#learning-structure) (go down to the units, with no more than 4 learning objectives) (Name of your folder e.g. `Learning Unit Template`)
	2. [Licensing and Attribution](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%203%20%E2%80%93%20Design/05-Hierarchical%20Structure/05-HierarchicalStructure/#licensing-and-attribution)
	3. [Develop your learning unit](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%203%20%E2%80%93%20Design/06-Learning%20unit%20development/06-LearningUnitDevelopment/) (`Learning Unit Template`)
		1. [Learning unit plan](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%203%20%E2%80%93%20Design/06-Learning%20unit%20development/06-LearningUnitDevelopment/#learning-unit-plan) (`template_unit_lesson_plan.md`)
		2. [Learning content](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%203%20%E2%80%93%20Design/06-Learning%20unit%20development/06-LearningUnitDevelopment/#learning-content) (`template_content.md`, `Learning_unit_content.pptx`)
		3. [Activity](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%203%20%E2%80%93%20Design/06-Learning%20unit%20development/06-LearningUnitDevelopment/#activity-details) (`Activities` --> `activity_details_template.md`)
		4. [Assessment](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%203%20%E2%80%93%20Design/06-Learning%20unit%20development/06-LearningUnitDevelopment/#assessment) (`Assessment` --> `assessment_template.md`)
	4. [Instructional design and facilitation](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%203%20%E2%80%93%20Design/07-Facilitation/07-Facilitation/)(`template_facilitator_guide.md`)
4. **PRODUCE**:
	1. Produce your learning content by using the [FAIR-by-design Methodology e.g. with GitHub and Markdown](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%204%20%E2%80%93%20Produce/08-Development%20Tools/08-Introduction%20to%20Markdown%20and%20Git/)
	2. Make the [accessibility check](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%205%20%E2%80%93%20Publish/17-Zenodo%20Publishing/17-Zenodo%20Publishing/)
	3. Finalize your content
		1. [Syllabus with metadata](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%204%20%E2%80%93%20Produce/12-Content%20Finalisation/12-Content_finalisation/#syllabus-and-machine-readable-metadata)(also check that all learning units have metadata) (`syllabus.md`)
		2. [LICENSE file](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%204%20%E2%80%93%20Produce/12-Content%20Finalisation/12-Content_finalisation/#updating-the-license) (`LICENCE`)
		3. [Facilitation guide](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%204%20%E2%80%93%20Produce/12-Content%20Finalisation/12-Content_finalisation/#defining-the-facilitation-guide) (`template_facilitator_guide.md`)
		4. Feedback form (if not for Skills4EOSC) (`Feedback` --> `training_feedback_template.md`)
	4. [Internal QA-Check](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%204%20%E2%80%93%20Produce/13-Internal%20QA/13-Internal_QA/)
5. **PUBLISH:**
	1. [CITATION.cff](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%205%20%E2%80%93%20Publish/16-Publishing%20Preparations/16-Publishing%20Preparations/#filling-out-citationcff) (`CITATION.cff`)
	2. [README.md](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%205%20%E2%80%93%20Publish/16-Publishing%20Preparations/16-Publishing%20Preparations/#filling-out-readmemd) (`README.md`)
	3. [CODE_OF_CONDUCT.md](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%205%20%E2%80%93%20Publish/16-Publishing%20Preparations/16-Publishing%20Preparations/#filling-out-code_of_conductmd) (`CODE_OF_CONDUCT.md`)
	4. Final step: Publish your content on [Zenodo](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%205%20%E2%80%93%20Publish/17-Zenodo%20Publishing/17-Zenodo%20Publishing/)
6. **VERIFY:**
	1. [QA](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%206%20%E2%80%93%20Verify/19-Final%20QA%20check/19-finalQA/)
	2. Collect feedback and from that [improve your content](https://fair-by-design-methodology.github.io/FAIR-by-Design_ToT/latest/Stage%206%20%E2%80%93%20Verify/20-Continuous%20Improvement/20-CI/), don't forget about versioning
